# biliarchiver

## 基于 bilix 的 BiliBili 存档工具

~~ IA iteam identifier 格式兼容 tubeup ~~。  
现在不兼容了，Tubeup 不适合存 B 站视频，它的 identifier 设计不科学，大规模存档必定会撞车。

目前，我可能随时 commit 乱飞且动不动就 git push -f 这个仓库。（为了在我的 vps 和本地之间同步代码）

userscript.js 还没适配新换的 identifier 格式。
